Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(113)

Unified Diff: cc/raster/raster_source.h

Issue 2877483003: Implements core logic for Pixel Canvas (Closed)
Patch Set: nit Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: cc/raster/raster_source.h
diff --git a/cc/raster/raster_source.h b/cc/raster/raster_source.h
index 92e429bd24fe37f8b560233e25569fdcaf369f15..99ff1ca2ee71e09d6a737176d315cb0f2459579f 100644
--- a/cc/raster/raster_source.h
+++ b/cc/raster/raster_source.h
@@ -87,10 +87,10 @@ class CC_EXPORT RasterSource : public base::RefCountedThreadSafe<RasterSource> {
const gfx::ColorSpace& target_color_space,
const PlaybackSettings& settings) const;
// Returns whether the given rect at given scale is of solid color in
// this raster source, as well as the solid color value.
- bool PerformSolidColorAnalysis(const gfx::Rect& content_rect,
- float contents_scale,
+ bool PerformSolidColorAnalysis(gfx::Rect content_rect,
+ const gfx::AxisTransform2d& raster_transform,
SkColor* color) const;
// Returns true iff the whole raster source is of solid color.
@@ -87,10 +87,10 @@ class CC_EXPORT RasterSource : public base::RefCountedThreadSafe<RasterSource> {
const gfx::ColorSpace& target_color_space,
const PlaybackSettings& settings) const;
- // Returns whether the given rect at given scale is of solid color in
+ // Returns whether the given rect with |raster_transform| is of solid color in
// this raster source, as well as the solid color value.

Powered by Google App Engine
This is Rietveld 408576698